@@ -24,7 +24,8 @@ class RedoSpecGramForm(forms.Form):
     ManualF2 = forms.FloatField(required=False,label='Manual F2')
 
 class AnalysisForm(forms.Form):
-    M_CHOICES = (('S','SSANOVA-style'),
+    M_CHOICES = (('N','None'),
+                ('S','SSANOVA-style'),
                 ('M','Midpoint'),
                 ('D','Dispersion'))
     if 'celex' in settings.INSTALLED_APPS:
@@ -78,12 +79,12 @@ class AnalysisForm(forms.Form):
     wasRepeated = forms.BooleanField(initial=False,required=False,label='Was repeated')
     wordDuration = forms.BooleanField(initial=True,required=False,label='Word duration')
     segmentalDurations = forms.BooleanField(initial=True,required=False,label='Segmental duration')
-    category = forms.CharField(blank=True,label='Category source')
+    category = forms.CharField(required=False,label='Category source')
     category.widget = forms.CheckboxSelectMultiple(choices=CAT_CHOICES)
     frequency = forms.BooleanField(initial=True,required=False,label='Frequency')
     nd = forms.BooleanField(initial=True,required=False,label='Neighbourhood density')
     phonotactic = forms.BooleanField(initial=True,required=False,label='Phonotactic probability')
-    lexical_scale = forms.CharField(blank=True,label = 'Corpora to use for lexical statistics')
+    lexical_scale = forms.CharField(required=False,label = 'Corpora to use for lexical statistics')
     lexical_scale.widget = forms.CheckboxSelectMultiple(choices=LEX_SCALE_CHOICES)
     additional_phono_stats = forms.BooleanField(initial=False,required=False,label='Additional phonological statistics')
     gender = forms.BooleanField(initial=True,required=False,label='Gender')
@@ -95,9 +96,9 @@ class AnalysisForm(forms.Form):
     prev_sem_pred = forms.BooleanField(initial=True,required=False,label='Previous semantic predictability')
     foll_sem_pred = forms.BooleanField(initial=True,required=False,label='Following semantic predictability')
     pause_dist = forms.BooleanField(initial=True,required=False,label='Distance to pauses')
-    sem_pred_window = forms.CharField(blank=True,label='Semantic predictability window')
+    sem_pred_window = forms.CharField(required=False,label='Semantic predictability window')
     sem_pred_window.widget = forms.CheckboxSelectMultiple(choices=SEM_PRED_WINDOW)
-    sem_pred_style = forms.CharField(blank=True,label='Semantic predictability style')
+    sem_pred_style = forms.CharField(required=False,label='Semantic predictability style')
     sem_pred_style.widget = forms.CheckboxSelectMultiple(choices=SEM_PRED_STYLE)
 
     #force_fetch = forms.CharField(label='Force fetch')
@@ -195,7 +196,8 @@ class AnalysisForm(forms.Form):
                 wanted_fields += ['AHDispersion']
             else:
                 wanted_fields += ['Dispersion']
-        wanted_fields += ['F1','F2']
+        if form['measure'] != 'N':
+            wanted_fields += ['F1','F2']
         return wanted_fields
 
     class Meta:
