@@ -130,10 +130,10 @@ class Speaker(caching.base.CachingMixin,models.Model):
         Dialog.objects.bulk_create([ Dialog(Speaker=self,Number=d) for d in dialogs])
 
     def analyze(self,form):
-        words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker').filter(Dialog__Speaker=self)
-        words = words.filter(WordType__CVSkel='CVC')
-        words = words.filter(WordType__Label__in = GOOD_WORDS)
-        words = words.filter(WordType__StressVowel__in = MONOPHTHONGS)
+        words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker').filter(WordType__Label__regex = '^[^{<]').filter(Dialog__Speaker=self)
+        #words = words.filter(WordType__CVSkel='CVC')
+        #words = words.filter(WordType__Label__in = GOOD_WORDS)
+        #words = words.filter(WordType__StressVowel__in = MONOPHTHONGS)
         allout = []
         print(str(self))
         print("\n")
@@ -145,7 +145,10 @@ class Speaker(caching.base.CachingMixin,models.Model):
                 continue
             if str(w.Dialog) == 's2003' or str(w.Dialog) =='s4001':
                 continue
-            allout.extend(w.getAnalysisLines(form))
+            out = w.getAnalysisLines(form)
+            if out is None:
+                continue
+            allout.extend(out)
             if settings.DEBUG:
                 print allout[-1]
         return allout
@@ -827,41 +830,6 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 numSylls += 1
         return numSylls
 
-    def getNumVows(self):
-        numVows = 0
-        for seg in self.SR.all():
-            if seg.isVowel():
-                numVows += 1
-        return numVows
-
-    def containsNasal(self):
-        for seg in self.SR.all():
-            if seg.isNasal():
-                return True
-        return False
-
-    def obsCheck(self):
-        for s in self.SR.all():
-            if not s.isVowel() and not s.isObs():
-                return False
-        for s in self.WordType.UR.all():
-            if not s.isVowel() and not s.isObs():
-                return False
-        return True
-
-    def vowPosCheck(self):
-        sr = self.SR.all()
-        ur = self.WordType.UR.all()
-        if sr[0].isVowel():
-            return False
-        if sr[sr.count()-1].isVowel():
-            return False
-        if ur[0].isVowel():
-            return False
-        if ur[ur.count()-1].isVowel():
-            return False
-        return True
-
     def getDuration(self):
         return self.End - self.Begin
 
@@ -980,10 +948,6 @@ class WordToken(caching.base.CachingMixin,models.Model):
     def isAcceptable(self):
         if self.nextToPause():
             return False
-        if self.getNumVows() != 1:
-            return False
-        if not self.vowPosCheck():
-            return False
         return True
 
     def getAnalysisLines(self,output_form):
@@ -1028,8 +992,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 else:
                     outline['wasRepeated'] = 'False'
 
-        if 'C' in form['category'] + form['lexical_scale']:
-            celex_info = get_lexical_info(self.WordType.Label)
+        celex_info = get_lexical_info(self.WordType.Label)
 
         if 'B' in form['category']:
             if 'BuckeyeCategory' not in outline:
@@ -1040,6 +1003,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
                     outline['CelexCategory'] = celex_info['Cat']
                 except KeyError:
                     outline['CelexCategory'] = 'NA'
+        if outline['CelexCategory'] not in ['N','ADV','A','V']:
+            return None
 
         if form['wordDuration']:
             if 'WordDuration' not in outline:
@@ -1276,48 +1241,3 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 'Speaker':speak}
 
         return out
-
-
-#class SynSemCase(models.Model):
-    #verb = models.ForeignKey(WordToken)
-    #checked = models.NullBooleanField()
-    #complement = models.CharField(max_length=10,blank=True)
-
-    #def getNoun(self):
-        #foll = self.verb.getFollowingWord()
-        #dets = set(['a','an','the','this','these','those'])
-        #if foll.WordType.Label not in dets and foll.WordType.Label != '<SIL>':
-            #return foll
-        #else:
-            #return foll.getFollowingWord()
-
-    #def getInter(self):
-        #inter = []
-        #n = self.getNoun()
-        #f = self.verb.getFollowingWord()
-        #for i in range(10):
-            #if f == n:
-                #return inter
-            #inter.append(f)
-            #f = f.getFollowingWord()
-
-
-    #def getPrev(self):
-        #prevs = []
-        #p = self.verb.getPreviousWord()
-        #for i in range(10):
-            #if p is None:
-                #break
-            #prevs.append(p)
-            #p = p.getPreviousWord()
-        #return reversed(prevs)
-
-    #def getFoll(self):
-        #folls = []
-        #f = self.getNoun().getFollowingWord()
-        #for i in range(10):
-            #if f is None:
-                #break
-            #folls.append(f)
-            #f = f.getFollowingWord()
-        #return folls
